@@ -2,7 +2,7 @@ package Object::Sub;
 
 use strict;
 
-our $VERSION = '0.102';
+our $VERSION = '0.103';
 
 our $AUTOLOAD;
 
@@ -27,6 +27,13 @@ sub AUTOLOAD {
 sub new {
   my ($class, $cb) = @_;
 
+  if (ref $cb eq 'HASH') {
+    my $orig_cb = $cb;
+    $cb = sub {
+      ($orig_cb->{$_[1]} || die "unable to find method $_[1]")->($_[0], @_[2 .. $#_]);
+    };
+  }
+
   die "need a callback" if ref $cb ne 'CODE';
 
   my $self = { cb => $cb, };
@@ -70,6 +77,22 @@ Object::Sub - Create objects without those pesky classes
     ## self: Object::Sub=HASH(0xc78eb0), method name: , first arg: 123
     ##   ($method is undef)
 
+Alternatively, you can use a hash of subs:
+
+    my $obj = Object::Sub->new({
+        add => sub {
+            my ($self, $num1, $num2) = @_;
+            return $num1 + $num2;
+        },
+        mul => sub {
+            my ($self, $num1, $num2) = @_;
+            return $num1 * $num2;
+        },
+    });
+
+    $obj->add(2, 3);
+    ## => 5
+
 =head1 DESCRIPTION
 
 Sometimes you want something that acts like an object but you don't want to go to all the trouble of creating a new package, with constructor and methods and so on. This module is a trivial wrapper around perl's L<AUTOLOAD> functionality which intercepts method calls and lets you handle them in a single C<sub>. It also uses L<overload> so that you can additionally treat the object as a C<sub> if you desire.
